==> galeon-1.3.0.tar.gz: galeon-1.3.0/utils/prefs-strings.h <==
/* General */
#define CONF_GENERAL_HOMEPAGE "/apps/galeon/Browsing/General/startpage"
#define CONF_GENERAL_STARTPAGE_TYPE "/apps/galeon/Browsing/General/startpage_type"
#define CONF_GENERAL_ALWAYS_SAVE_SESSION "/apps/galeon/Browsing/General/always_save_session"
#define CONF_GENERAL_NEWPAGE_TYPE "/apps/galeon/Browsing/General/newpage_type"

/* Bookmarks */
#define CONF_BOOKMARKS_TITLE "/apps/galeon/Browsing/Bookmarks/bookmark_title"
#define CONF_BOOKMARKS_XITEMS "/apps/galeon/Browsing/Bookmarks/bm_extra_items_location"
#define CONF_BOOKMARKS_ENTRY_WIDTH "/apps/galeon/Browsing/Bookmarks/smart_bm_entry_width"
#define CONF_BOOKMARKS_HISTORY "/apps/galeon/Browsing/Bookmarks/smart_bm_history"
#define CONF_BOOKMARKS_CLEAR "/apps/galeon/Browsing/Bookmarks/smart_bm_clear"
#define CONF_BOOKMARKS_TOOLTIPS "/apps/galeon/Browsing/Bookmarks/bm_tooltips"
#define CONF_BOOKMARKS_SMARTBOOKMARK_HIDE_ARROWS "/apps/galeon/Browsing/Bookmarks/smartbookmarks_hide_arrows"
#define CONF_BOOKMARKS_REMOVE_CONFIRMATION_MIN "/apps/galeon/Browsing/Bookmarks/remove_confirmation_min"
#define CONF_BOOKMARKS_AB_ENABLED "/apps/galeon/Browsing/Bookmarks/autobookmarks_enabled"
#define CONF_BOOKMARKS_AB_COUNT "/apps/galeon/Browsing/Bookmarks/autobookmarks_count"
#define CONF_BOOKMARKS_AB_SHORTEN "/apps/galeon/Browsing/Bookmarks/autobookmarks_shorten"
#define CONF_BOOKMARKS_SHORTTEXT "/apps/galeon/Browsing/Bookmarks/shorttext"

/* Autocompletion */
#define CONF_HISTORY_AUTOCOMP_ENABLE "/apps/galeon/Browsing/History/completion_enabled"
#define CONF_COMPLETION_SHOW_LIST_AUTO "/apps/galeon/Browsing/History/completion_show_list_auto"
#define CONF_COMPLETION_MAX_SHORT "/apps/galeon/Browsing/History/completion_max_short"
#define CONF_COMPLETION_SHOW_TITLES "/apps/galeon/Browsing/History/completion_show_titles"
#define CONF_COMPLETION_HUGE_WINDOW "/apps/galeon/Browsing/History/completion_huge"

/* Tabs */
#define CONF_TABS_TABBED "/apps/galeon/UI/Tabs/tabbed"
#define CONF_TABS_TABBED_POPUPS "/apps/galeon/UI/Tabs/tabbed_popups"
#define CONF_TABS_TABBED_AUTOJUMP "/apps/galeon/UI/Tabs/tabbed_autojump"
#define CONF_TABS_TABBED_LOADING_COLOR "/apps/galeon/UI/Tabs/tabbed_loading_color"
#define CONF_TABS_TABBED_NEW_COLOR "/apps/galeon/UI/Tabs/tabbed_new_color"
#define CONF_TABS_TABBED_ALWAYS_SHOW "/apps/galeon/UI/Tabs/tabbed_always_show"

/* Window appeareance */
#define CONF_WINDOWS_SIDEBAR_PAGE "/apps/galeon/UI/Windows/sidebar_page"
#define CONF_WINDOWS_SIDEBAR_SIZE "/apps/galeon/UI/Windows/sidebar_size"
#define CONF_WINDOWS_FS_SHOW_SIDEBAR "/apps/galeon/UI/Windows/show_sidebar_in_fullscreen"
#define CONF_WINDOWS_FS_SHOW_MENUBAR "/apps/galeon/UI/Windows/show_menubar_in_fullscreen"
#define CONF_WINDOWS_FS_SHOW_TOOLBARS "/apps/galeon/UI/Windows/show_toolbars_in_fullscreen"
#define CONF_WINDOWS_FS_SHOW_BOOKMARKS "/apps/galeon/UI/Windows/show_bookmarks_in_fullscreen"
#define CONF_WINDOWS_FS_SHOW_STATUSBAR "/apps/galeon/UI/Windows/show_statusbar_in_fullscreen"
#define CONF_WINDOWS_SHOW_SIDEBAR "/apps/galeon/UI/Windows/show_sidebar"
#define CONF_WINDOWS_SHOW_MENUBAR "/apps/galeon/UI/Windows/show_menubar"
#define CONF_WINDOWS_SHOW_TOOLBARS "/apps/galeon/UI/Windows/show_toolbars"
#define CONF_WINDOWS_SHOW_BOOKMARKS "/apps/galeon/UI/Windows/show_bookmarks"
#define CONF_WINDOWS_SHOW_STATUSBAR "/apps/galeon/UI/Windows/show_statusbar"
#define CONF_WINDOWS_SHOW_DOCK "/apps/galeon/UI/Windows/show_dock"
#define CONF_TOOLBAR_SPINNER_THEME "/apps/galeon/UI/Toolbar/spinner_theme"
#define CONF_TOOLBAR_SETUP "/apps/galeon/UI/Toolbar/setup"

/* External apps */
#define CONF_PROGRAMS_GNOME_MAILER "/apps/galeon/Handlers/Programs/gnome_mailer"
#define CONF_PROGRAMS_MAILER "/apps/galeon/Handlers/Programs/mailer"
#define CONF_DOWNLOADING_ASK_DIR "/apps/galeon/Handlers/Downloading/ask_for_download_dir"
#define CONF_DOWNLOADING_SHOW_DETAILS "/apps/galeon/Handlers/Downloading/show_details"
#define CONF_DOWNLOADING_EXTERNAL_DOWNLOADER "/apps/galeon/Handlers/Downloading/external_downloader"
#define CONF_DOWNLOADING_EXTERNAL_COMMAND "/apps/galeon/Handlers/Downloading/external_download_command"
#define CONF_DOWNLOADING_EXTERNAL_TERMINAL "/apps/galeon/Handlers/Downloading/external_download_terminal"
#define CONF_STATE_LAST_DOWNLOAD_DIR "/apps/galeon/State/last_download_dir"
#define CONF_DOWNLOADING_DIR "/apps/galeon/Handlers/Downloading/download_dir"

/* State */ 
#define CONF_STATE_SAVE_DIR           "/apps/galeon/State/savedir"
#define CONF_STATE_SAVE_IMAGE_DIR     "/apps/galeon/State/saveimagedir"
#define CONF_STATE_OPEN_DIR           "/apps/galeon/State/opendir"

/* mouse */
#define CONF_MOUSE_MIDDLE_BUTTON_ACTION "/apps/galeon/UI/Mouse/middle_button_action"
#define CONF_MOUSE_RIGHT_BUTTON_GESTURES "/apps/galeon/UI/Mouse/mouse_right_button_gestures"

/* System prefs */
#define CONF_DESKTOP_FTP_HANDLER "/desktop/gnome/url-handlers/ftp/command"	

#define CONF_DESKTOP_TOOLBAR_STYLE "/desktop/gnome/interface/toolbar_style"

==> galeon-1.3.3.tar.gz: galeon-1.3.3/utils/prefs-strings.h <==
/* General */
#define CONF_GENERAL_HOMEPAGE "/apps/galeon/Browsing/General/startpage"
#define CONF_GENERAL_STARTPAGE_TYPE "/apps/galeon/Browsing/General/startpage_type"
#define CONF_GENERAL_ALWAYS_SAVE_SESSION "/apps/galeon/Browsing/General/always_save_session"
#define CONF_GENERAL_NEWPAGE_TYPE "/apps/galeon/Browsing/General/newpage_type"

/* Bookmarks */
#define CONF_BOOKMARKS_TITLE "/apps/galeon/Browsing/Bookmarks/bookmark_title"
#define CONF_BOOKMARKS_XITEMS "/apps/galeon/Browsing/Bookmarks/bm_extra_items_location"
#define CONF_BOOKMARKS_ENTRY_WIDTH "/apps/galeon/Browsing/Bookmarks/smart_bm_entry_width"
#define CONF_BOOKMARKS_HISTORY "/apps/galeon/Browsing/Bookmarks/smart_bm_history"
#define CONF_BOOKMARKS_CLEAR "/apps/galeon/Browsing/Bookmarks/smart_bm_clear"
#define CONF_BOOKMARKS_TOOLTIPS "/apps/galeon/Browsing/Bookmarks/bm_tooltips"
#define CONF_BOOKMARKS_SMARTBOOKMARK_HIDE_ARROWS "/apps/galeon/Browsing/Bookmarks/smartbookmarks_hide_arrows"
#define CONF_BOOKMARKS_REMOVE_CONFIRMATION_MIN "/apps/galeon/Browsing/Bookmarks/remove_confirmation_min"
#define CONF_BOOKMARKS_AB_ENABLED "/apps/galeon/Browsing/Bookmarks/autobookmarks_enabled"
#define CONF_BOOKMARKS_AB_COUNT "/apps/galeon/Browsing/Bookmarks/autobookmarks_count"
#define CONF_BOOKMARKS_AB_SHORTEN "/apps/galeon/Browsing/Bookmarks/autobookmarks_shorten"
#define CONF_BOOKMARKS_SHORTTEXT "/apps/galeon/Browsing/Bookmarks/shorttext"

/* Autocompletion */
#define CONF_HISTORY_AUTOCOMP_ENABLE "/apps/galeon/Browsing/History/completion_enabled"
#define CONF_COMPLETION_SHOW_LIST_AUTO "/apps/galeon/Browsing/History/completion_show_list_auto"
#define CONF_COMPLETION_MAX_SHORT "/apps/galeon/Browsing/History/completion_max_short"
#define CONF_COMPLETION_SHOW_TITLES "/apps/galeon/Browsing/History/completion_show_titles"
#define CONF_COMPLETION_HUGE_WINDOW "/apps/galeon/Browsing/History/completion_huge"

/* Tabs */
#define CONF_TABS_TABBED "/apps/galeon/UI/Tabs/tabbed"
#define CONF_TABS_TABBED_POPUPS "/apps/galeon/UI/Tabs/tabbed_popups"
#define CONF_TABS_TABBED_AUTOJUMP "/apps/galeon/UI/Tabs/tabbed_autojump"
#define CONF_TABS_TABBED_LOADING_COLOR "/apps/galeon/UI/Tabs/tabbed_loading_color"
#define CONF_TABS_TABBED_NEW_COLOR "/apps/galeon/UI/Tabs/tabbed_new_color"
#define CONF_TABS_TABBED_ALWAYS_SHOW "/apps/galeon/UI/Tabs/tabbed_always_show"

/* Window appeareance */
#define CONF_WINDOWS_SIDEBAR_PAGE "/apps/galeon/UI/Windows/sidebar_page"
#define CONF_WINDOWS_SIDEBAR_SIZE "/apps/galeon/UI/Windows/sidebar_size"
#define CONF_WINDOWS_FS_SHOW_SIDEBAR "/apps/galeon/UI/Windows/show_sidebar_in_fullscreen"
#define CONF_WINDOWS_FS_SHOW_MENUBAR "/apps/galeon/UI/Windows/show_menubar_in_fullscreen"
#define CONF_WINDOWS_FS_SHOW_TOOLBARS "/apps/galeon/UI/Windows/show_toolbars_in_fullscreen"
#define CONF_WINDOWS_FS_SHOW_BOOKMARKS "/apps/galeon/UI/Windows/show_bookmarks_in_fullscreen"
#define CONF_WINDOWS_FS_SHOW_STATUSBAR "/apps/galeon/UI/Windows/show_statusbar_in_fullscreen"
#define CONF_WINDOWS_SHOW_SIDEBAR "/apps/galeon/UI/Windows/show_sidebar"
#define CONF_WINDOWS_SHOW_MENUBAR "/apps/galeon/UI/Windows/show_menubar"
#define CONF_WINDOWS_SHOW_TOOLBARS "/apps/galeon/UI/Windows/show_toolbars"
#define CONF_WINDOWS_SHOW_BOOKMARKS "/apps/galeon/UI/Windows/show_bookmarks"
#define CONF_WINDOWS_SHOW_STATUSBAR "/apps/galeon/UI/Windows/show_statusbar"
#define CONF_WINDOWS_SHOW_DOCK "/apps/galeon/UI/Windows/show_dock"
#define CONF_TOOLBAR_SPINNER_THEME "/apps/galeon/UI/Toolbar/spinner_theme"
#define CONF_TOOLBAR_SETUP "/apps/galeon/UI/Toolbar/setup"
#define CONF_TOOLBAR_STYLE "/apps/galeon/UI/Toolbar/toolbar_style"

/* External apps */
#define CONF_PROGRAMS_GNOME_MAILER "/apps/galeon/Handlers/Programs/gnome_mailer"
#define CONF_PROGRAMS_MAILER "/apps/galeon/Handlers/Programs/mailer"
#define CONF_DOWNLOADING_ASK_DIR "/apps/galeon/Handlers/Downloading/ask_for_download_dir"
#define CONF_DOWNLOADING_SHOW_DETAILS "/apps/galeon/Handlers/Downloading/show_details"
#define CONF_DOWNLOADING_EXTERNAL_DOWNLOADER "/apps/galeon/Handlers/Downloading/external_downloader"
#define CONF_DOWNLOADING_EXTERNAL_COMMAND "/apps/galeon/Handlers/Downloading/external_download_command"
#define CONF_DOWNLOADING_EXTERNAL_TERMINAL "/apps/galeon/Handlers/Downloading/external_download_terminal"
#define CONF_STATE_LAST_DOWNLOAD_DIR "/apps/galeon/State/last_download_dir"
#define CONF_DOWNLOADING_DIR "/apps/galeon/Handlers/Downloading/download_dir"

/* State */ 
#define CONF_STATE_SAVE_DIR           "/apps/galeon/State/savedir"
#define CONF_STATE_SAVE_IMAGE_DIR     "/apps/galeon/State/saveimagedir"
#define CONF_STATE_OPEN_DIR           "/apps/galeon/State/opendir"

/* mouse */
#define CONF_MOUSE_MIDDLE_BUTTON_ACTION "/apps/galeon/UI/Mouse/middle_button_action"
#define CONF_MOUSE_RIGHT_BUTTON_ACTION "/apps/galeon/UI/Mouse/right_button_action"

/* System prefs */
#define CONF_DESKTOP_FTP_HANDLER "/desktop/gnome/url-handlers/ftp/command"	

#define CONF_DESKTOP_TOOLBAR_STYLE "/desktop/gnome/interface/toolbar_style"
